@@ -1,6 +1,4 @@
 __all__ = ['zafira_state', 'client', 'resource_constants', 'resources', 'plugin', 'listener']
 
-from .zafira_state import ZafiraState
-from .client import ZafiraClient
 from .plugin import connector_obj
 from .listener import PyTestZafiraListener
